/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="PdfSaveOptionsData.java">
 *   Copyright (c) 2021 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

package com.aspose.words.cloud.model;

import java.util.Objects;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.List;
import java.io.IOException;
import org.threeten.bp.OffsetDateTime;
import com.aspose.words.cloud.model.*;
import com.google.gson.TypeAdapter;
import com.google.gson.annotations.JsonAdapter;
import com.google.gson.annotations.SerializedName;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * Container class for pdf save options.
 */
@ApiModel(description = "Container class for pdf save options.")
public class PdfSaveOptionsData extends FixedPageSaveOptionsData {
    /**
     * Gets or sets the option that controls how bookmarks in headers/footers are exported.
     * The default value is Aspose.Words.Saving.HeaderFooterBookmarksExportMode.All.
     */
    @JsonAdapter(HeaderFooterBookmarksExportModeEnum.Adapter.class)
    public enum HeaderFooterBookmarksExportModeEnum {
        NONE("None"),
        FIRST("First"),
        ALL("All");

        private String value;

        HeaderFooterBookmarksExportModeEnum(String value) {
            this.value = value;
        }

        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        public static HeaderFooterBookmarksExportModeEnum fromValue(String text) {
            for (HeaderFooterBookmarksExportModeEnum b : HeaderFooterBookmarksExportModeEnum.values()) {
                if (String.valueOf(b.value).equals(text)) {
                    return b;
                }
            }
            return null;
        }

        public static class Adapter extends TypeAdapter< HeaderFooterBookmarksExportModeEnum > {
            @Override
            public void write(final JsonWriter jsonWriter, final HeaderFooterBookmarksExportModeEnum enumeration) throws IOException {
                jsonWriter.value(enumeration.getValue());
            }

            @Override
            public HeaderFooterBookmarksExportModeEnum read(final JsonReader jsonReader) throws IOException {
                String value = jsonReader.nextString();
                return HeaderFooterBookmarksExportModeEnum.fromValue(String.valueOf(value));
            }
        }
    }

    @SerializedName("Compliance")
    private String compliance = null;

    @SerializedName("CreateNoteHyperlinks")
    private Boolean createNoteHyperlinks = null;

    @SerializedName("CustomPropertiesExport")
    private String customPropertiesExport = null;

    @SerializedName("DigitalSignatureDetails")
    private PdfDigitalSignatureDetailsData digitalSignatureDetails = null;

    @SerializedName("DisplayDocTitle")
    private Boolean displayDocTitle = null;

    @SerializedName("DownsampleOptions")
    private DownsampleOptionsData downsampleOptions = null;

    @SerializedName("EmbedFullFonts")
    private Boolean embedFullFonts = null;

    @SerializedName("EncryptionDetails")
    private PdfEncryptionDetailsData encryptionDetails = null;

    @SerializedName("ExportDocumentStructure")
    private Boolean exportDocumentStructure = null;

    @SerializedName("ExportLanguageToSpanTag")
    private Boolean exportLanguageToSpanTag = null;

    @SerializedName("FontEmbeddingMode")
    private String fontEmbeddingMode = null;

    @SerializedName("HeaderFooterBookmarksExportMode")
    private HeaderFooterBookmarksExportModeEnum headerFooterBookmarksExportMode = null;

    @SerializedName("ImageColorSpaceExportMode")
    private String imageColorSpaceExportMode = null;

    @SerializedName("ImageCompression")
    private String imageCompression = null;

    @SerializedName("InterpolateImages")
    private Boolean interpolateImages = null;

    @SerializedName("OpenHyperlinksInNewWindow")
    private Boolean openHyperlinksInNewWindow = null;

    @SerializedName("OutlineOptions")
    private OutlineOptionsData outlineOptions = null;

    @SerializedName("PageMode")
    private String pageMode = null;

    @SerializedName("PreblendImages")
    private Boolean preblendImages = null;

    @SerializedName("PreserveFormFields")
    private Boolean preserveFormFields = null;

    @SerializedName("TextCompression")
    private String textCompression = null;

    @SerializedName("UseBookFoldPrintingSettings")
    private Boolean useBookFoldPrintingSettings = null;

    @SerializedName("UseCoreFonts")
    private Boolean useCoreFonts = null;

    @SerializedName("ZoomBehavior")
    private String zoomBehavior = null;

    @SerializedName("ZoomFactor")
    private Integer zoomFactor = null;
    public PdfSaveOptionsData compliance(String compliance) {
        this.compliance = compliance;
        return this;
    }

    /**
     * Gets or sets the PDF standards compliance level for output documents.
    * @return compliance
    **/
    @ApiModelProperty(value = "Gets or sets the PDF standards compliance level for output documents.")
    public String getCompliance() {
        return compliance;
    }

    public void setCompliance(String compliance) {
        this.compliance = compliance;
    }

    public PdfSaveOptionsData createNoteHyperlinks(Boolean createNoteHyperlinks) {
        this.createNoteHyperlinks = createNoteHyperlinks;
        return this;
    }

    /**
     * Gets or sets a value indicating whether to convert footnote/endnote references in main text story into active hyperlinks.
     * When clicked the hyperlink will lead to the corresponding footnote/endnote.
     * The default value is false.
    * @return createNoteHyperlinks
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether to convert footnote/endnote references in main text story into active hyperlinks. When clicked the hyperlink will lead to the corresponding footnote/endnote. The default value is false.")
    public Boolean getCreateNoteHyperlinks() {
        return createNoteHyperlinks;
    }

    public void setCreateNoteHyperlinks(Boolean createNoteHyperlinks) {
        this.createNoteHyperlinks = createNoteHyperlinks;
    }

    public PdfSaveOptionsData customPropertiesExport(String customPropertiesExport) {
        this.customPropertiesExport = customPropertiesExport;
        return this;
    }

    /**
     * Gets or sets the option that controls the way CustomDocumentProperties are exported to PDF file.
     * The default value is None.
    * @return customPropertiesExport
    **/
    @ApiModelProperty(value = "Gets or sets the option that controls the way CustomDocumentProperties are exported to PDF file. The default value is None.")
    public String getCustomPropertiesExport() {
        return customPropertiesExport;
    }

    public void setCustomPropertiesExport(String customPropertiesExport) {
        this.customPropertiesExport = customPropertiesExport;
    }

    public PdfSaveOptionsData digitalSignatureDetails(PdfDigitalSignatureDetailsData digitalSignatureDetails) {
        this.digitalSignatureDetails = digitalSignatureDetails;
        return this;
    }

    /**
     * Gets or sets the details for signing the output PDF document.
    * @return digitalSignatureDetails
    **/
    @ApiModelProperty(value = "Gets or sets the details for signing the output PDF document.")
    public PdfDigitalSignatureDetailsData getDigitalSignatureDetails() {
        return digitalSignatureDetails;
    }

    public void setDigitalSignatureDetails(PdfDigitalSignatureDetailsData digitalSignatureDetails) {
        this.digitalSignatureDetails = digitalSignatureDetails;
    }

    public PdfSaveOptionsData displayDocTitle(Boolean displayDocTitle) {
        this.displayDocTitle = displayDocTitle;
        return this;
    }

    /**
     * Gets or sets a value indicating whether the window’s title bar should display the document title taken from the Title entry of the document information dictionary.
    * @return displayDocTitle
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether the window’s title bar should display the document title taken from the Title entry of the document information dictionary.")
    public Boolean getDisplayDocTitle() {
        return displayDocTitle;
    }

    public void setDisplayDocTitle(Boolean displayDocTitle) {
        this.displayDocTitle = displayDocTitle;
    }

    public PdfSaveOptionsData downsampleOptions(DownsampleOptionsData downsampleOptions) {
        this.downsampleOptions = downsampleOptions;
        return this;
    }

    /**
     * Gets or sets the downsample options.
    * @return downsampleOptions
    **/
    @ApiModelProperty(value = "Gets or sets the downsample options.")
    public DownsampleOptionsData getDownsampleOptions() {
        return downsampleOptions;
    }

    public void setDownsampleOptions(DownsampleOptionsData downsampleOptions) {
        this.downsampleOptions = downsampleOptions;
    }

    public PdfSaveOptionsData embedFullFonts(Boolean embedFullFonts) {
        this.embedFullFonts = embedFullFonts;
        return this;
    }

    /**
     * Gets or sets a value indicating whether fonts are embedded into the resulting PDF documents.
    * @return embedFullFonts
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether fonts are embedded into the resulting PDF documents.")
    public Boolean getEmbedFullFonts() {
        return embedFullFonts;
    }

    public void setEmbedFullFonts(Boolean embedFullFonts) {
        this.embedFullFonts = embedFullFonts;
    }

    public PdfSaveOptionsData encryptionDetails(PdfEncryptionDetailsData encryptionDetails) {
        this.encryptionDetails = encryptionDetails;
        return this;
    }

    /**
     * Gets or sets the details for encrypting the output PDF document.
    * @return encryptionDetails
    **/
    @ApiModelProperty(value = "Gets or sets the details for encrypting the output PDF document.")
    public PdfEncryptionDetailsData getEncryptionDetails() {
        return encryptionDetails;
    }

    public void setEncryptionDetails(PdfEncryptionDetailsData encryptionDetails) {
        this.encryptionDetails = encryptionDetails;
    }

    public PdfSaveOptionsData exportDocumentStructure(Boolean exportDocumentStructure) {
        this.exportDocumentStructure = exportDocumentStructure;
        return this;
    }

    /**
     * Gets or sets a value indicating whether to export document structure.
    * @return exportDocumentStructure
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether to export document structure.")
    public Boolean getExportDocumentStructure() {
        return exportDocumentStructure;
    }

    public void setExportDocumentStructure(Boolean exportDocumentStructure) {
        this.exportDocumentStructure = exportDocumentStructure;
    }

    public PdfSaveOptionsData exportLanguageToSpanTag(Boolean exportLanguageToSpanTag) {
        this.exportLanguageToSpanTag = exportLanguageToSpanTag;
        return this;
    }

    /**
     * Gets or sets a value determining whether or not to create a "Span" tag in the document structure to export the text language.
    * @return exportLanguageToSpanTag
    **/
    @ApiModelProperty(value = "Gets or sets a value determining whether or not to create a \"Span\" tag in the document structure to export the text language.")
    public Boolean getExportLanguageToSpanTag() {
        return exportLanguageToSpanTag;
    }

    public void setExportLanguageToSpanTag(Boolean exportLanguageToSpanTag) {
        this.exportLanguageToSpanTag = exportLanguageToSpanTag;
    }

    public PdfSaveOptionsData fontEmbeddingMode(String fontEmbeddingMode) {
        this.fontEmbeddingMode = fontEmbeddingMode;
        return this;
    }

    /**
     * Gets or sets the font embedding mode.
    * @return fontEmbeddingMode
    **/
    @ApiModelProperty(value = "Gets or sets the font embedding mode.")
    public String getFontEmbeddingMode() {
        return fontEmbeddingMode;
    }

    public void setFontEmbeddingMode(String fontEmbeddingMode) {
        this.fontEmbeddingMode = fontEmbeddingMode;
    }

    public PdfSaveOptionsData headerFooterBookmarksExportMode(HeaderFooterBookmarksExportModeEnum headerFooterBookmarksExportMode) {
        this.headerFooterBookmarksExportMode = headerFooterBookmarksExportMode;
        return this;
    }

    /**
     * Gets or sets the option that controls how bookmarks in headers/footers are exported.
     * The default value is Aspose.Words.Saving.HeaderFooterBookmarksExportMode.All.
    * @return headerFooterBookmarksExportMode
    **/
    @ApiModelProperty(value = "Gets or sets the option that controls how bookmarks in headers/footers are exported. The default value is Aspose.Words.Saving.HeaderFooterBookmarksExportMode.All.")
    public HeaderFooterBookmarksExportModeEnum getHeaderFooterBookmarksExportMode() {
        return headerFooterBookmarksExportMode;
    }

    public void setHeaderFooterBookmarksExportMode(HeaderFooterBookmarksExportModeEnum headerFooterBookmarksExportMode) {
        this.headerFooterBookmarksExportMode = headerFooterBookmarksExportMode;
    }

    public PdfSaveOptionsData imageColorSpaceExportMode(String imageColorSpaceExportMode) {
        this.imageColorSpaceExportMode = imageColorSpaceExportMode;
        return this;
    }

    /**
     * Gets or sets the option that controls how the color space will be selected for the images in PDF document.
    * @return imageColorSpaceExportMode
    **/
    @ApiModelProperty(value = "Gets or sets the option that controls how the color space will be selected for the images in PDF document.")
    public String getImageColorSpaceExportMode() {
        return imageColorSpaceExportMode;
    }

    public void setImageColorSpaceExportMode(String imageColorSpaceExportMode) {
        this.imageColorSpaceExportMode = imageColorSpaceExportMode;
    }

    public PdfSaveOptionsData imageCompression(String imageCompression) {
        this.imageCompression = imageCompression;
        return this;
    }

    /**
     * Gets or sets the compression type to be used for all images in the document.
    * @return imageCompression
    **/
    @ApiModelProperty(value = "Gets or sets the compression type to be used for all images in the document.")
    public String getImageCompression() {
        return imageCompression;
    }

    public void setImageCompression(String imageCompression) {
        this.imageCompression = imageCompression;
    }

    public PdfSaveOptionsData interpolateImages(Boolean interpolateImages) {
        this.interpolateImages = interpolateImages;
        return this;
    }

    /**
     * Gets or sets a value indicating whether image interpolation shall be performed by a conforming reader. When false is specified, the flag is not written to the output document and the default behavior of reader is used instead.
    * @return interpolateImages
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether image interpolation shall be performed by a conforming reader. When false is specified, the flag is not written to the output document and the default behavior of reader is used instead.")
    public Boolean getInterpolateImages() {
        return interpolateImages;
    }

    public void setInterpolateImages(Boolean interpolateImages) {
        this.interpolateImages = interpolateImages;
    }

    public PdfSaveOptionsData openHyperlinksInNewWindow(Boolean openHyperlinksInNewWindow) {
        this.openHyperlinksInNewWindow = openHyperlinksInNewWindow;
        return this;
    }

    /**
     * Gets or sets a value indicating whether hyperlinks in the output Pdf document are forced to be opened in a new window (or tab) of a browser.
    * @return openHyperlinksInNewWindow
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether hyperlinks in the output Pdf document are forced to be opened in a new window (or tab) of a browser.")
    public Boolean getOpenHyperlinksInNewWindow() {
        return openHyperlinksInNewWindow;
    }

    public void setOpenHyperlinksInNewWindow(Boolean openHyperlinksInNewWindow) {
        this.openHyperlinksInNewWindow = openHyperlinksInNewWindow;
    }

    public PdfSaveOptionsData outlineOptions(OutlineOptionsData outlineOptions) {
        this.outlineOptions = outlineOptions;
        return this;
    }

    /**
     * Gets or sets the outline options.
    * @return outlineOptions
    **/
    @ApiModelProperty(value = "Gets or sets the outline options.")
    public OutlineOptionsData getOutlineOptions() {
        return outlineOptions;
    }

    public void setOutlineOptions(OutlineOptionsData outlineOptions) {
        this.outlineOptions = outlineOptions;
    }

    public PdfSaveOptionsData pageMode(String pageMode) {
        this.pageMode = pageMode;
        return this;
    }

    /**
     * Gets or sets the option that controls how the PDF document should be displayed when opened in the PDF reader.
    * @return pageMode
    **/
    @ApiModelProperty(value = "Gets or sets the option that controls how the PDF document should be displayed when opened in the PDF reader.")
    public String getPageMode() {
        return pageMode;
    }

    public void setPageMode(String pageMode) {
        this.pageMode = pageMode;
    }

    public PdfSaveOptionsData preblendImages(Boolean preblendImages) {
        this.preblendImages = preblendImages;
        return this;
    }

    /**
     * Gets or sets a value indicating whether to preblend transparent images with black background color.
    * @return preblendImages
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether to preblend transparent images with black background color.")
    public Boolean getPreblendImages() {
        return preblendImages;
    }

    public void setPreblendImages(Boolean preblendImages) {
        this.preblendImages = preblendImages;
    }

    public PdfSaveOptionsData preserveFormFields(Boolean preserveFormFields) {
        this.preserveFormFields = preserveFormFields;
        return this;
    }

    /**
     * Gets or sets a value indicating whether to preserve Microsoft Word form fields as form fields in PDF or convert them to text.
    * @return preserveFormFields
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether to preserve Microsoft Word form fields as form fields in PDF or convert them to text.")
    public Boolean getPreserveFormFields() {
        return preserveFormFields;
    }

    public void setPreserveFormFields(Boolean preserveFormFields) {
        this.preserveFormFields = preserveFormFields;
    }

    public PdfSaveOptionsData textCompression(String textCompression) {
        this.textCompression = textCompression;
        return this;
    }

    /**
     * Gets or sets the compression type to be used for all textual content in the document.
    * @return textCompression
    **/
    @ApiModelProperty(value = "Gets or sets the compression type to be used for all textual content in the document.")
    public String getTextCompression() {
        return textCompression;
    }

    public void setTextCompression(String textCompression) {
        this.textCompression = textCompression;
    }

    public PdfSaveOptionsData useBookFoldPrintingSettings(Boolean useBookFoldPrintingSettings) {
        this.useBookFoldPrintingSettings = useBookFoldPrintingSettings;
        return this;
    }

    /**
     * Gets or sets a value indicating whether the document should be saved using a booklet printing layout.
    * @return useBookFoldPrintingSettings
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether the document should be saved using a booklet printing layout.")
    public Boolean getUseBookFoldPrintingSettings() {
        return useBookFoldPrintingSettings;
    }

    public void setUseBookFoldPrintingSettings(Boolean useBookFoldPrintingSettings) {
        this.useBookFoldPrintingSettings = useBookFoldPrintingSettings;
    }

    public PdfSaveOptionsData useCoreFonts(Boolean useCoreFonts) {
        this.useCoreFonts = useCoreFonts;
        return this;
    }

    /**
     * Gets or sets a value indicating whether to substitute TrueType fonts Arial, Times New Roman, Courier New and Symbol with core PDF Type 1 fonts.
    * @return useCoreFonts
    **/
    @ApiModelProperty(value = "Gets or sets a value indicating whether to substitute TrueType fonts Arial, Times New Roman, Courier New and Symbol with core PDF Type 1 fonts.")
    public Boolean getUseCoreFonts() {
        return useCoreFonts;
    }

    public void setUseCoreFonts(Boolean useCoreFonts) {
        this.useCoreFonts = useCoreFonts;
    }

    public PdfSaveOptionsData zoomBehavior(String zoomBehavior) {
        this.zoomBehavior = zoomBehavior;
        return this;
    }

    /**
     * Gets or sets the option that controls what type of zoom should be applied when a document is opened with a PDF viewer.
    * @return zoomBehavior
    **/
    @ApiModelProperty(value = "Gets or sets the option that controls what type of zoom should be applied when a document is opened with a PDF viewer.")
    public String getZoomBehavior() {
        return zoomBehavior;
    }

    public void setZoomBehavior(String zoomBehavior) {
        this.zoomBehavior = zoomBehavior;
    }

    public PdfSaveOptionsData zoomFactor(Integer zoomFactor) {
        this.zoomFactor = zoomFactor;
        return this;
    }

    /**
     * Gets or sets the zoom factor (in percentages) for a document.
    * @return zoomFactor
    **/
    @ApiModelProperty(value = "Gets or sets the zoom factor (in percentages) for a document.")
    public Integer getZoomFactor() {
        return zoomFactor;
    }

    public void setZoomFactor(Integer zoomFactor) {
        this.zoomFactor = zoomFactor;
    }

    @Override
    public boolean equals(java.lang.Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        PdfSaveOptionsData pdfSaveOptionsData = (PdfSaveOptionsData) o;
        return
            Objects.equals(this.compliance, pdfSaveOptionsData.compliance) &&
            Objects.equals(this.createNoteHyperlinks, pdfSaveOptionsData.createNoteHyperlinks) &&
            Objects.equals(this.customPropertiesExport, pdfSaveOptionsData.customPropertiesExport) &&
            Objects.equals(this.digitalSignatureDetails, pdfSaveOptionsData.digitalSignatureDetails) &&
            Objects.equals(this.displayDocTitle, pdfSaveOptionsData.displayDocTitle) &&
            Objects.equals(this.downsampleOptions, pdfSaveOptionsData.downsampleOptions) &&
            Objects.equals(this.embedFullFonts, pdfSaveOptionsData.embedFullFonts) &&
            Objects.equals(this.encryptionDetails, pdfSaveOptionsData.encryptionDetails) &&
            Objects.equals(this.exportDocumentStructure, pdfSaveOptionsData.exportDocumentStructure) &&
            Objects.equals(this.exportLanguageToSpanTag, pdfSaveOptionsData.exportLanguageToSpanTag) &&
            Objects.equals(this.fontEmbeddingMode, pdfSaveOptionsData.fontEmbeddingMode) &&
            Objects.equals(this.headerFooterBookmarksExportMode, pdfSaveOptionsData.headerFooterBookmarksExportMode) &&
            Objects.equals(this.imageColorSpaceExportMode, pdfSaveOptionsData.imageColorSpaceExportMode) &&
            Objects.equals(this.imageCompression, pdfSaveOptionsData.imageCompression) &&
            Objects.equals(this.interpolateImages, pdfSaveOptionsData.interpolateImages) &&
            Objects.equals(this.openHyperlinksInNewWindow, pdfSaveOptionsData.openHyperlinksInNewWindow) &&
            Objects.equals(this.outlineOptions, pdfSaveOptionsData.outlineOptions) &&
            Objects.equals(this.pageMode, pdfSaveOptionsData.pageMode) &&
            Objects.equals(this.preblendImages, pdfSaveOptionsData.preblendImages) &&
            Objects.equals(this.preserveFormFields, pdfSaveOptionsData.preserveFormFields) &&
            Objects.equals(this.textCompression, pdfSaveOptionsData.textCompression) &&
            Objects.equals(this.useBookFoldPrintingSettings, pdfSaveOptionsData.useBookFoldPrintingSettings) &&
            Objects.equals(this.useCoreFonts, pdfSaveOptionsData.useCoreFonts) &&
            Objects.equals(this.zoomBehavior, pdfSaveOptionsData.zoomBehavior) &&
            Objects.equals(this.zoomFactor, pdfSaveOptionsData.zoomFactor) &&
            super.equals(o);
  }

  @Override
  public int hashCode() {
    return Objects.hash(compliance, createNoteHyperlinks, customPropertiesExport, digitalSignatureDetails, displayDocTitle, downsampleOptions, embedFullFonts, encryptionDetails, exportDocumentStructure, exportLanguageToSpanTag, fontEmbeddingMode, headerFooterBookmarksExportMode, imageColorSpaceExportMode, imageCompression, interpolateImages, openHyperlinksInNewWindow, outlineOptions, pageMode, preblendImages, preserveFormFields, textCompression, useBookFoldPrintingSettings, useCoreFonts, zoomBehavior, zoomFactor, super.hashCode());
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class PdfSaveOptionsData {\n");
    sb.append("    ").append(toIndentedString(super.toString())).append("\n");
    sb.append("    compliance: ").append(toIndentedString(compliance)).append("\n");
    sb.append("    createNoteHyperlinks: ").append(toIndentedString(createNoteHyperlinks)).append("\n");
    sb.append("    customPropertiesExport: ").append(toIndentedString(customPropertiesExport)).append("\n");
    sb.append("    digitalSignatureDetails: ").append(toIndentedString(digitalSignatureDetails)).append("\n");
    sb.append("    displayDocTitle: ").append(toIndentedString(displayDocTitle)).append("\n");
    sb.append("    downsampleOptions: ").append(toIndentedString(downsampleOptions)).append("\n");
    sb.append("    embedFullFonts: ").append(toIndentedString(embedFullFonts)).append("\n");
    sb.append("    encryptionDetails: ").append(toIndentedString(encryptionDetails)).append("\n");
    sb.append("    exportDocumentStructure: ").append(toIndentedString(exportDocumentStructure)).append("\n");
    sb.append("    exportLanguageToSpanTag: ").append(toIndentedString(exportLanguageToSpanTag)).append("\n");
    sb.append("    fontEmbeddingMode: ").append(toIndentedString(fontEmbeddingMode)).append("\n");
    sb.append("    headerFooterBookmarksExportMode: ").append(toIndentedString(headerFooterBookmarksExportMode)).append("\n");
    sb.append("    imageColorSpaceExportMode: ").append(toIndentedString(imageColorSpaceExportMode)).append("\n");
    sb.append("    imageCompression: ").append(toIndentedString(imageCompression)).append("\n");
    sb.append("    interpolateImages: ").append(toIndentedString(interpolateImages)).append("\n");
    sb.append("    openHyperlinksInNewWindow: ").append(toIndentedString(openHyperlinksInNewWindow)).append("\n");
    sb.append("    outlineOptions: ").append(toIndentedString(outlineOptions)).append("\n");
    sb.append("    pageMode: ").append(toIndentedString(pageMode)).append("\n");
    sb.append("    preblendImages: ").append(toIndentedString(preblendImages)).append("\n");
    sb.append("    preserveFormFields: ").append(toIndentedString(preserveFormFields)).append("\n");
    sb.append("    textCompression: ").append(toIndentedString(textCompression)).append("\n");
    sb.append("    useBookFoldPrintingSettings: ").append(toIndentedString(useBookFoldPrintingSettings)).append("\n");
    sb.append("    useCoreFonts: ").append(toIndentedString(useCoreFonts)).append("\n");
    sb.append("    zoomBehavior: ").append(toIndentedString(zoomBehavior)).append("\n");
    sb.append("    zoomFactor: ").append(toIndentedString(zoomFactor)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
